Connection Pools
================

.. automodule:: urllib3.connectionpool

.. autoclass:: urllib3.HTTPConnectionPool
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: urllib3.HTTPSConnectionPool
    :members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: urllib3.connectionpool.ConnectionPool
    :members:
    :undoc-members:
    :show-inheritance:

.. autofunction:: urllib3.connectionpool.connection_from_url
